#!/bin/sh

set_env() {
    set -e
    set -vx

    cdir=$(dirname "$0")
    cd "$cdir"/..

    idir=debian/update
    mkdir -p "$idir"

    export CODENAME= #FIXME
}

is_set_distr_version() {
    test -z "$DISTR_VERSION" || {
        VERSION="$DISTR_VERSION"
        return 0
    }
    test -z "$VERSION" || {
        VERSION=$(echo "$VERSION" | tr '[:upper:]' '[:lower:]')
        return 0
    }

    return 1
}

error() {
    echo "Error: $*"
    exit 1
}

set_edition() {
    local e
    e="$1"

    if test -n "$EDITION"
    then
        test "$EDITION" = "$e"
    else
        EDITION="$e"
    fi
}

set_codename() {
    local c
    c="$1"

    if test -n "$CODENAME"
    then
        test "$CODENAME" = "$c"
    else
        CODENAME="$c"
    fi
    CODENAME_BIG=$(echo "$CODENAME" | sed -e 's/^./\U&/')
}

parse_profiles() {
    echo "DEB_BUILD_PROFILES = $DEB_BUILD_PROFILES"
    case " $DEB_BUILD_PROFILES " in
        *' astrase '*)
            set_edition SE
            ;;
        *)
            set_edition CE
    esac

    test -n "$ARCH" || ARCH=$(dpkg --print-architecture)
    D_CALLBACK="$ARCH"_"$EDITION"
    case "$ARCH" in
        armhf|arm64)
            ;;
        e2k-8c)
            test "$EDITION" = SE
            D_CALLBACK=leningrad
            ;;
        amd64)
            ;;
        *)
            error "Unsupported ARCH $ARCH"
            ;;
    esac

    case " $DEB_BUILD_PROFILES " in
        *\ astrabuster\ *)
            . src/buster.sh
            ;;
        *)
            . src/stretch.sh
            ;;
    esac
    set_"$D_CALLBACK"
}

get_version_v_v() {
    echo "$VERSION" | awk -F . '{ print $1"."$2 }'
}

get_version_v_v_v() {
    echo "$VERSION" | awk -F . '{ print $1"."$2"."$3 }'
}

get_version_1() {
    echo "$VERSION" | awk -F . '{ print $1 }'
}

get_version_2() {
    echo "$VERSION" | awk -F . '{ print $2 }'
}

get_version_3() {
    echo "$VERSION" | awk -F . '{ print $3 }'
}

get_version_4() {
    echo "$VERSION" | awk -F . '{ print $4 }'
}

append_version_v_v_v_v() {
    awk -F . '{
        if (!$2) $2 = "0"
        if (!$3) $3 = "0"
        if (!$4) $4 = "0"
        print $1"."$2"."$3"."$4
    }'
}

set_version_prefix() {
    local prefix
    prefix="$1"

    is_set_distr_version || VERSION=$(get_astra_version)

    case "$VERSION" in
        "$prefix".*)
            ;;
        *)
            error "Incorrect VERSION $VERSION"
    esac
}

update_pkg_version() {
    PKG_VERSION=${PKG_VERSION:-v"$VERSION"}

    local old_version
    old_version=$(dpkg-parsechangelog -S Version)
    local prefix
    prefix=$(echo "$old_version" | sed -e 's/\+v.*//')
    local new_version
    new_version="$prefix"+"$PKG_VERSION"
    echo "$new_version" >debian/deb_version
}

create_build_version() {
    local extrepo
    extrepo=$(get_version_4 | sed -e 's/[0-9]\+//')
    
    sed -e "s&#VERSION#&$VERSION&g" debian/postinst.in >debian/postinst

    test -n "$extrepo" || return 0

    case "$extrepo" in
        krea|ext|custom)
            break
            ;;
        *)
            error "Unknown ext repo $extrepo"
            ;;
    esac
}

create_issues() {
    local v
    v=$(cat "$idir"/astra_version)

    {
        echo -n "Astra Linux $v "
        printf '\\n \\l\n'
    } >"$idir"/issue
    echo "Astra Linux $v" >"$idir"/issue.net
}

get_update_version_from_file() {
    awk '/^Update / { print $2 }' "$1"
}

get_distr_bulletin() {
    echo $(date +"%Y%m%d")SE$(get_version_1)$(get_version_2)
}

create_astra_update_version() {
    test "$EDITION" = SE || return 0

    local u_version
    u_version=$(get_version_3)

    test ! -f src/astra_update_version_"$CODENAME" || {
        cp src/astra_update_version_"$CODENAME" "$idir"/astra_update_version
        test "$u_version" = 0 || test $(get_update_version_from_file "$idir"/astra_update_version) = "$u_version"
        return 0
    }
    DISTR_BULLETIN=${DISTR_BULLETIN:-$(get_distr_bulletin)}

    cat <<EOF >"$idir"/astra_update_version
Update $u_version
Bulletin $DISTR_BULLETIN
EOF
    return 0
}

set_env
parse_profiles
update_pkg_version

create_astra_version >"$idir"/astra_version
create_build_version
create_astra_update_version
create_lsb_release >"$idir"/lsb-release
create_os_release >"$idir"/os-release
create_issues

